SystemOrganization addCategory: #ConfigurationOfDeli!

Object subclass: #ConfigurationOfDeli
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDeli'!

!ConfigurationOfDeli commentStamp: '<historical>' prior: 0!
Copy me to start a new project!

!ConfigurationOfDeli class methodsFor: 'private' stamp: 'tfel 11/30/2010 16:30'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfDeli class methodsFor: 'private' stamp: 'tfel 11/30/2010 16:30'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfDeli class methodsFor: 'metacello tool support' stamp: 'tfel 11/30/2010 16:30'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDeli class methodsFor: 'metacello tool support' stamp: 'tfel 11/30/2010 16:30'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfDeli class methodsFor: 'loading' stamp: 'tfel 11/30/2010 16:30'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfDeli class methodsFor: 'metacello tool support' stamp: 'tfel 11/30/2010 16:30'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfDeli class methodsFor: 'accessing' stamp: 'tfel 11/30/2010 16:30'!
project

	^self new project! !

!ConfigurationOfDeli class methodsFor: 'unloading Metacello' stamp: 'tfel 11/30/2010 16:30'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfDeli methodsFor: 'baselines' stamp: 'tfel 11/30/2010 17:17'!
baseline100: spec 
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository:
				'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swe09-team13';
			project: 'Seaside28' with: [
				spec
					className: 'ConfigurationOfSeaside28';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Magritte' with: [
				spec
					className: 'ConfigurationOfMagritte';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #( 'Magritte-Seaside' ) ];
			
			package: 'Deli' with: [ spec requires: #('Seaside28') ];
			package: 'DeliMagritte' with: [ spec requires: #('Deli' 'Magritte') ];
			yourself ].

	spec for: #squeakCommon do: [
		spec 
			package: 'DeliSqueak' with: [ spec requires: #('Deli') ];
			group: 'default' with: #('Deli' 'DeliMagritte' 'DeliSqueak');
			yourself ].

	spec for: #gemstone do: [
		spec group: 'default' with: #('Deli' 'DeliMagritte'); yourself ].! !

!ConfigurationOfDeli methodsFor: 'accessing' stamp: 'tfel 11/30/2010 16:30'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfDeli methodsFor: 'versions' stamp: 'tfel 11/30/2010 18:31'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >

	spec for: #common do: [
		spec 
			blessing: #release;
			package: 'Deli' with: 'Deli-tfel.392';
			package: 'DeliSqueak' with: 'DeliSqueak-tfel.3';
			package: 'DeliMagritte' with: 'DeliMagritte-topa.1' ].
! !
